/****************
 ! Gnome clocks *
*****************/

@include exports("gnome-clocks") {
    .clocks-analog-frame {
        &.trough { color: mix($fg_color, $bg_color, .85); }

        &.progress { color: mix($bg_color, $selected_bg_color, .5); }

        &.progress-fast { color: shade($selected_bg_color, .7); }
    }
}


/*****************
 ! Gnome Builder *
******************/

@include exports("gnome-builder") {
    workbench.csd > stack.titlebar:not(headerbar) {
        padding: 0;
        background: none;
        border: 0;
        box-shadow: none;

        headerbar {
            &, &:first-child, &:last-child { border-radius: $roundness $roundness 0 0; }
        }
    }
}


/************************
 ! Unity-Control-Center *
*************************/

@include exports("unity-control-center") {
    // Fixed: https://github.com/numixproject/numix-gtk-theme/issues/634
    .background:not(.csd):not(.solid-csd) > box.vertical > notebook.frame {
        // hide unwanted frames
        border: 0 none transparent;

        > stack > scrolledwindow > viewport > box.vertical > frame > box.vertical {
            // reset $base_color;
            iconview.view {
                &, &:backdrop {
                    background-color: transparent;
                }

                &:selected {
                    &:focus, & {
                        @extend %selected_items;
                    }
                }
            }
        }
    }
}


/****************
 ! Geary *
*****************/

@include exports("geary") {
   .geary-expanded .geary-message-summary {
	    background-color: shade($base_color, 0.95);
    }
    
    .geary-folder-popover-list-row {
        border-color: shade($menu_bg_color, 1.2);
        box-shadow: None;
        
        & > label { color: $bg_color; }
    }
    
}
