/*******************
 ! Spinner animation
********************/

@include exports("spinner") {
    @keyframes spin {
        to { -gtk-icon-transform: rotate(1turn); }
    }

    .spinner {
        background-image: none;
        background-color: $selected_bg_color;
        opacity: 0; // non spinning spinner makes no sense

        -gtk-icon-source: -gtk-icontheme("process-working-symbolic");

        &:active {
            opacity: 1;
            animation: spin 1s linear infinite;

            &:insensitive { opacity: .5; }
        }
    }
}
