/*********
 ! Gedit *
**********/

@include exports("gedit") {
    GeditWindow .pane-separator {
        border-width: 0 1px 0 0;
        border-style: solid;

        &, &:hover {
            border-color: shade($bg_color, ($contrast + .1));
            background-color: $bg_color;
        }
    }

    .gedit-document-panel {
        background-color: $bg_color;
        color: mix($fg_color, $bg_color, .1);

        list row {
            padding: $spacing;

            button {
                padding: 1px;
                border-radius: $roundness;
                border-style: solid;
                border-color: transparent;
                border-width: 1px;
                background-color: transparent;
                background-image: none;
                color: transparent;
                -gtk-icon-shadow: none;
            }
        }

        .prelight-row button {
            border-color: alpha($black, .1);
            color: alpha($white, .8);

            &:active {
                border-color: alpha($black, .2);
                background-color: alpha($black, .08);
                color: $white;
            }
        }

        list row, .prelight-row {
            button:hover {
                border-color: alpha($black, .1);
                color: $white;
            }
        }
    }

    .gedit-document-panel-group-row {
        &, &:hover {
            border-top: 1px solid shade($bg_color, ($contrast + .1));
            background-color: $bg_color;
        }
    }

    .gedit-document-panel-document-row {
        &:hover { background-color: shade($bg_color, 1.05); }

        &:selected {
            &, &:hover { @extend %selected; }
        }
    }

    .gedit-document-panel-dragged-row {
        border: 1px solid alpha($black, .1);
        background-color: alpha($black, .5);
        color: $white;
    }

    .gedit-document-panel-placeholder-row {
        border: 0;
        background-color: alpha($black, .08);
        transition: all 200ms ease-in;
    }

    //Ignore: Global double border separator.
    //statusbar { border-top: 1px solid border_normal($bg_color); }

    statusbar GeditSmallButton, GeditStatusMenuButton {
        text-shadow: none;

        button {
            border-style: solid;
            border-width: 0 1px;
            border-color: transparent;
            border-radius: 0;
            padding: 1px 6px 2px 4px;

            &:hover, &:active, &:active:hover { border-color: border_normal($bg_color); }

            &:active {
                background-color: shade($bg_color, .95);
                color: $fg_color;
            }
        }
    }

    GeditViewFrame .gedit-search-slider {
        padding: $spacing;
        border-radius: 0 0 $roundness $roundness;
        border-width: 0 1px 1px;
        border-style: solid;
        border-color: border_normal($base_color);
        background-color: $base_color;

        .not-found {
            background-color: $error_bg_color;
            background-image: none;
            color: $error_fg_color;

            &:selected { @extend %selected; }
        }
    }

    GeditFileBrowserWidget .toolbar {
        padding: $spacing / 2;
        border-top: 0;
        background-color: $bg_color;
        background-image: none;
    }

    .gedit-search-entry-occurrences-tag {
        margin: $spacing / 2;
        padding: $spacing / 2;
        color: mix($text_color, $base_color, .5);
    }

    .gedit-bottom-panel-paned,
    .gedit-side-panel-paned,
    paned.titlebar {
        margin-right: 0;
    }

    .gedit-bottom-panel-paned notebook {
        border-top: none;
    }
}
