@import "panel";

/****************
 ! Unity styles *
*****************/

@include exports("unity") {
    UnityDecoration {
        -UnityDecoration-extents: 24px 1px 1px 1px;
        -UnityDecoration-input-extents: 10px;

        -UnityDecoration-shadow-offset-x: 1px;
        -UnityDecoration-shadow-offset-y: 1px;
        -UnityDecoration-active-shadow-color: rgba(0, 0, 0, .7);
        -UnityDecoration-active-shadow-radius: 8px;
        -UnityDecoration-inactive-shadow-color: rgba(0, 0, 0, .5);
        -UnityDecoration-inactive-shadow-radius: 5px;

        -UnityDecoration-glow-size: 10px;
        -UnityDecoration-glow-color: $selected_bg_color;

        -UnityDecoration-title-indent: 10px;
        -UnityDecoration-title-fade: 35px;
        -UnityDecoration-title-alignment: 0;


        .top {
            border: 1px solid $wm_border_focused;
            border-bottom: 0;
            border-radius: $roundness $roundness 0 0;
            padding: 1px ($spacing + 3px) 0 ($spacing + 3px);
            background-color: $titlebar_bg_color;
            color: mix($titlebar_fg_color, $titlebar_bg_color, .1);
            text-shadow: none;

            // Fixed: https://github.com/numixproject/numix-gtk-theme/issues/632
            // for L.I.M's selected menuitem
            &:hover {
                border-radius: 0;
                border-color: mix($panel_bg_color, $panel_fg_color, .21);
                background-color: mix($panel_bg_color, $panel_fg_color, .21);
                background-image: none;
                color: shade($panel_fg_color, 1.08);
            }

            &:backdrop {
                border: 1px solid $wm_border_unfocused;
                color: mix($titlebar_fg_color, $titlebar_bg_color, .4);
            }
        }

        .left, .right, .bottom {
            background-color: $titlebar_bg_color;

            &:backdrop { background-color: mix(shade($titlebar_bg_color, .7), $titlebar_fg_color, .21); }
        }
    }

    UnityPanelWidget, .unity-panel {
        @extend %panel;

        border: 0;
    }

    .unity-panel {
        &.menuitem, .menuitem {
            border-width: 0 1px;
            color: $panel_fg_color;

            &:hover, *:hover {
                border-color: mix($panel_bg_color, $panel_fg_color, .21);
                background-color: mix($panel_bg_color, $panel_fg_color, .21);
                background-image: none;
                color: shade($panel_fg_color, 1.08);
            }
        }
    }

    SheetStyleDialog.unity-force-quit { background-color: $bg_color; }
}
