/***********************
 ! LightDM GTK Greeter *
 ***********************/

@include exports("lightdm") {
    #panel_window {
        background-color: $lightdm_bg_color;
        background-image: none;
        color: $white;
        font-weight: bold;
        text-shadow: 0 1px alpha($black, .5);
        -gtk-icon-shadow: 0 1px alpha($black, .5);

        menubar {
            padding-left: $spacing;
            
            &, > menuitem {
                background-color: transparent;
                background-image: none;
                border-style: none;
                color: $white;
                text-shadow: 0 1px alpha($black, .5);
                -gtk-icon-shadow: 0 1px alpha($black, .5);

                &:hover {
                    background-color: alpha($white, .2);
                    background-image: none;
                    color: $white;
                }

                *:hover { color: $white; }

                &:disabled { color: alpha($white, .7); }
            }

            menu > menuitem { font-weight: normal; }
        }
    }

    #content_frame { padding-bottom: $spacing * 3; }

    #login_window, #shutdown_dialog, #restart_dialog {
        border-style: none;
        border-radius: $roundness;
        background-color: $lightdm_bg_color;
        color: $lightdm_fg_color;

        /* draw border using box-shadow */
        box-shadow: inset 1px 0 mix(shade($lightdm_bg_color, .7), $lightdm_fg_color, .21),
                    inset -1px 0 mix(shade($lightdm_bg_color, .7), $lightdm_fg_color, .21),
                    inset 0 1px mix(shade($lightdm_bg_color, .7), $lightdm_fg_color, .21),
                    inset 0 -1px mix(shade($lightdm_bg_color, .7), $lightdm_fg_color, .21);

        @extend %panelbutton;
    }

    #login_window {
        menu { border-radius: 0; }

        button { @include button($lightdm_bg_color, $lightdm_fg_color); }

        entry { @include entry($lightdm_bg_color, $lightdm_fg_color); }
    }

    #user_combobox {
        color: $lightdm_fg_color;
        font-size: 18px;

        menu { font-weight: normal; }

        arrow { color: mix($lightdm_fg_color, $lightdm_bg_color, .5); }
    }

    #user_image {
        border-radius: $roundness;

        /* draw border using box-shadow */
        box-shadow: inset 1px 0 shade($lightdm_bg_color, .7),
                    inset -1px 0 shade($lightdm_bg_color, .7),
                    inset 0 1px shade($lightdm_bg_color, .7),
                    inset 0 -1px shade($lightdm_bg_color, .7);
    }

    #user_image_border {
        border-radius: $roundness;
        background-color: shade($lightdm_bg_color, .9);
        background-image: none;
        box-shadow: inset 1px 0 alpha($dark_shadow, .07),
                    inset 0 1px alpha($dark_shadow, .08),
                    inset -1px 0 alpha($dark_shadow, .07),
                    inset 0 -1px alpha($dark_shadow, .05);
    }

    #buttonbox_frame {
        padding-top: $spacing * 2;
        padding-bottom: 0;
        border-style: none;
        border-bottom-left-radius: $roundness;
        border-bottom-right-radius: $roundness;
        background-color: transparent;
        background-image: none;
        box-shadow: none;
    }

    /* shutdown button */
    #shutdown_button {
        button { @include button($error_bg_color, $error_fg_color); }
    }

    /* restart button */
    #restart_button {
        button { @include button($warning_bg_color, $warning_fg_color); }
    }

     /* password warning */
    #greeter_infobar { font-weight: bold; }
}
