/***********************
 ! Unity Greeter *
 ***********************/

@include exports("unity-greeter") {
    @keyframes dashentry_spinner {
        to { -gtk-icon-transform: rotate(1turn); }
    }

    %lightdm-button {
        background-image: none;
        background-color: fade-out($black, .7);
        border-color: fade-out($white, .1);
        border-radius: ($roundness * 2) + 1px;
        padding: $spacing;
        color: $white;
    }

    .lightdm {
        &.menu {
            background-image: none;
            background-color: fade-out($black, .4);
            border-color: fade-out($white, .8);
            border-radius: $roundness * 2;
            padding: 1px;

            color: $white;

            .menuitem { *, &.check:active, &.radio:active { color: $white; } }
        }

        &.menubar { *, &.menuitem { padding: $spacing - 3px; } }

        &.option-button {
            padding: $spacing;
            background: none;
            border: 0;
        }

        &.toggle-button {
            background: none;
            border-width: 0;

            &.selected {
                background-color: fade-out($black, .7);
                border-color: fade-out($white, .7);
                border-width: 1px;

                &:hover { background-color: fade-out($white, .7); }
            }
        }

        &.button {
            @extend %lightdm-button;

            &:hover {
                background-color: fade-out($white, .7);
                border-color: fade-out($white, .4);
                text-shadow: none;
            }
        }

        &.entry, &.button:active, &.button:active:focus, &.button:focus {
            background-image: none;
            background-color: fade-out($black, .7);
            border-color: fade-out($white, .4);
            border-radius: ($roundness * 2) + 1px;
            padding: $spacing + 2px;
            color: $white;
            text-shadow: none;
        }

        &.entry {
            &:hover, &:active, &:active:focus {
                background-image: none;
                border-image: none;
            }

            &:active {
                -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
                animation: dashentry_spinner 1s infinite linear;
            }

            &:focus {
                border-color: fade-out($white, .4);
                border-width: 1px;
                border-style: solid;
                color: $white;
            }

            &:selected { background-color: fade-out($white, .8); }
        }
    }

    .lightdm-combo {
        &.combobox-entry .button, .cell, .button, .entry { @extend %lightdm-button; }

        &.menu {
            background-color: shade($dark_bg_color, 1.08);
            border-radius: 0;
            padding: 0;
            color: $white;
        }
    }
}
