@import "button";


/*********
 ! Infobar
**********/

@include exports("infobar") {
    GtkInfoBar {
        border: 0;
    }

    $types: (
        info: ($info_fg_color, $info_bg_color),
        warning: ($warning_fg_color, $warning_bg_color),
        question: ($question_fg_color, $question_bg_color),
        error: ($error_fg_color, $error_bg_color),
    );


    @each $type, $colors in $types {
        $fg_color: nth($colors, 1);
        $bg_color: nth($colors, 2);

        .#{$type} {
            @include linear-gradient($bg_color);

            border: 1px solid shade($bg_color, .8);
            color: $fg_color;

            .button {
                @include button($bg_color, $fg_color);

                &.close { @extend %close_button; }
            }
        }
    }
}
