/***********************
 ! Unity Greeter *
 ***********************/

@include exports("unity-greeter") {


    .lightdm.menu {
        background-image: none;
        background-color: fade-out($black, .4);
        border-color: fade-out($white, .8);
        border-radius: 4px;
        padding: 1px;

        color: $white;
    }

    .lightdm-combo .menu {
        background-color: shade($dark_bg_color, 1.08);
        border-radius: 0;
        padding: 0;
        color: $white;
    }

    .lightdm.menu .menuitem *,
    .lightdm.menu .menuitem.check:active,
    .lightdm.menu .menuitem.radio:active {
        color: $white;
    }

    .lightdm.menubar *,    
    .lightdm.menubar .menuitem {
        padding: 2px;
    }

    .lightdm-combo.combobox-entry .button,
    .lightdm-combo .cell,
    .lightdm-combo .button,
    .lightdm-combo .entry,
    
    .lightdm.button{
        background-image: none;
        background-color: fade-out($black, .7);
        border-color: fade-out($white, .1);
        border-radius: 5px;
        padding: 5px;
        color: $white;
        }
    .lightdm.button:hover {
        background-image: none;
        background-color: fade-out($white, .7);
        border-color: fade-out($white, .4);
        border-radius: 5px;
        padding: 5px;
        color: $white;
        text-shadow: none;
        }
    .lightdm.button:active,
    .lightdm.button:active:focused,
    .lightdm.button:focused,

    .lightdm.entry {
        background-image: none;
        background-color: fade-out($black, .7);
        border-color: fade-out($white, .4);
        border-radius: 5px;
        padding: 6px;
        color: $white;
        text-shadow: none;
    }
    .lightdm.entry:hover,
    .lightdm.entry:active,
    .lightdm.entry:active:focused {
        background-image: none;
        border-image: none;
    }
    .lightdm.entry:focused {
        border-color: fade-out($white, .4);
        border-width: 1px;
        border-style: solid;
        color: $white;
    }
    .lightdm.entry:selected {
        background-color: fade-out($white, .8);
    }

    @keyframes dashentry_spinner {
        to { -gtk-icon-transform: rotate(1turn); }
    }

    .lightdm.entry:active {
        -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
        animation: dashentry_spinner 1s infinite linear;
    }

    .lightdm.option-button {
        background: none;
        border-width: 0;
    }

    .lightdm.option-button:insensitive:insensitive {
        background: none;
    }

    .lightdm.toggle-button {
        background: none;
        border-width: 0;
    }
    .lightdm.toggle-button.selected:hover {
        background-color: fade-out($white, .7);
        border-color: fade-out($white, .7);
        border-width: 1px;
    }
    .lightdm.toggle-button.selected {
        background-color: fade-out($black, .7);
        border-color: fade-out($white, .7);
        border-width: 1px;
    }
}
