/************
 ! Nautilus *
*************/

@include exports("nautilus") {
    .nautilus-desktop.nautilus-canvas-item {
        color: $white;
        text-shadow: 1px 1px $black;

        &:active { color: $fg_color; }

        &:selected { color: $selected_fg_color; }

        &:active, &:prelight, &:selected { text-shadow: none; }
    }

    NautilusWindow {
        .toolbar {
            border-width: 0 0 1px;
            border-style: solid;
            border-color: border_normal($toolbar_bg_color);
        }

        .sidebar .frame { border: 0; }

        GtkPaned {
            border-width: 0 1px 0 0;
            border-style: solid;

            &, &:hover {
                border-color: shade($bg_color, ($contrast + .1));
                background-color: $bg_color;
            }
        }
    }

    NautilusNotebook {
        &.notebook {
            border-right-width: 0;
            border-left-width: 0;
            border-bottom-width: 0;
        }

        .frame { border: 0; }
    }

    NautilusQueryEditor {
        .toolbar {
            padding-top: $spacing - 1px;
            padding-bottom: $spacing - 2px;
            border-width: 1px 0 0;
            border-style: solid;
            border-color: $toolbar_bg_color;
            background-color: shade($toolbar_bg_color, .9);

            &:nth-child(2) { border-color: border_normal($toolbar_bg_color); }

            &.search-bar {
                border-top-width: 0;
                border-bottom-width: 0;
            }

            &, &.search-bar {
                &:last-child, &:only-child {
                    border-bottom-width: 1px;
                    border-bottom-color: border_normal($toolbar_bg_color);
                }
            }

        }
    }
}
