/***********************
 ! Fallback mode panel *
************************/

@include exports("panel") {
    %panel {
        @include linear-gradient($panel_bg_color);

        color: $panel_fg_color;
    }

    %panellabel {
        font-weight: normal;
        color: $panel_fg_color;
    }

    %panelbutton {
        border-width: 0 1px;
        border-radius: 0;
        border-color: transparent;
        background-color: transparent;
        background-image: none;
        color: $panel_fg_color;

        &:hover {
            @include linear-gradient(mix($panel_bg_color, $panel_fg_color, .11));

            border-color: mix($panel_bg_color, $panel_fg_color, .11);
            color: shade($panel_fg_color, 1.08);
        }

        &:active, &:checked {
            @include linear-gradient(mix($panel_bg_color, $panel_fg_color, .21), to top);

            border-color: mix($panel_bg_color, $panel_fg_color, .21);
            color: shade($panel_fg_color, 1.08);

            &:hover {
                @include linear-gradient(mix($panel_bg_color, $panel_fg_color, .31), to top);

                border-color: mix($panel_bg_color, $panel_fg_color, .31);
            }
        }
    }

    panel-plug,
    panel-toplevel.background {
        @extend %panel;

        padding: 0;
    }

    .gp-text-color {
        color: $black;
    }

    #clock-applet-button,
    #tasklist-button,
    #showdesktop-button {
        &, &:backdrop { @extend %panelbutton; }
    }

    panel-applet {
        border: 0;

        button {
            &, &:backdrop { @extend %panelbutton; }
        }
    }

    clock-box,
    panel-applet > menubar,
    panel-toplevel .gnome-panel-menu-bar {
        &, &:backdrop {
            @extend %panel;

            menuitem {
                @extend %panel;

                border: 0;

                label { @extend %panellabel; }
            }
        }
    }

    gp-calendar-window,
    #tasklist-button,
    #clock-applet-button,
    #showdesktop-button {
        label { @extend %panellabel; }
    }

    wnck-pager, wnck-tasklist { @extend %panel; }
}
