/************
 ! Synaptic *
*************/

@include exports("synaptic") {
    GtkWindow > GtkVBox > .dock {
        &, > GtkHBox > GtkToolbar {
            @include linear-gradient($toolbar-bg-color);

            padding: $spacing;
            border: 0;
            color: $toolbar_fg_color;
        }
    }
}
