@import "button";
@import "toolbar";

/**************
 ! Action-bar *
***************/

@include exports("actionbar") {
    actionbar > revealer > box {
        padding: $spacing;
        border-top: 1px solid $borders_color;

        &:backdrop { border-color: $backdrop_borders_color; }
    }
}


/****************************
 ! Search and Location bars *
*****************************/

@include exports("searchbar") {
    searchbar,
    .location-bar {
        @include linear-gradient(shade($bg_color, .98));

        border-width: 0 0 1px;
        border-style: solid;
        border-color: border_normal($bg_color);
        color: $fg_color;
    }
}


/******************
 ! Action buttons *
*******************/

@include exports("actionbuttons") {
    $types: (
        suggested: $success_color,
        destructive: $error-color
    );

    @each $type, $color in $types {
        .#{$type}-action {
            @include button($color, $selected_fg_color);
        }
    }
}


/******************
 ! Selection mode *
*******************/

@include exports("selectionmode") {
    headerbar,
    .titlebar:not(headerbar) {
        &.selection-mode {
            @include toolbar($selected_bg_color, $selected_fg_color);

            button {
                @include button($selected_bg_color, $selected_fg_color);

                &.suggested-action { @extend .suggested-action; }
            }

            &:backdrop {
                background-color: $backdrop_selected_bg_color;
                background-image: none;
            }

            .selection-menu {
                &:backdrop, & {
                    color: shade($selected_bg_color, $contrast);
                    background-color: transparent;
                    background-image: none;
                    box-shadow: none;
                    border: 0;

                    &:hover { color: shade($selected_bg_color, ($contrast - .1)); }

                    &:active { color: shade($selected_bg_color, ($contrast - .05)); }

                    .arrow {
                        -gtk-icon-source: -gtk-icontheme('pan-down-symbolic');
                        color: transparentize($selected_fg_color, .5);
                        -gtk-icon-shadow: none;
                    }
                }
            }

            .dim-label {
                &, .selection-menu & { color: shade($selected_bg_color, ($contrast - .1)); }
            }
        }
    }
}
