/***********************
 ! Fallback mode panel *
************************/

@include exports("panel") {
    %panel {
        @include linear-gradient($panel_bg_color);

        color: $panel_fg_color;
    }

    %panelbutton {
        border-width: 0 1px;
        border-radius: 0;
        border-color: transparent;
        background-color: transparent;
        background-image: none;
        color: $panel_fg_color;

        &:hover, &:prelight {
            @include linear-gradient(mix($panel_bg_color, $panel_fg_color, .11));

            border-color: mix($panel_bg_color, $panel_fg_color, .11);
            color: shade($panel_fg_color, 1.08);
        }

        &:active, &:checked {
            @include linear-gradient(mix($panel_bg_color, $panel_fg_color, .21), to top);

            border-color: mix($panel_bg_color, $panel_fg_color, .21);
            color: shade($panel_fg_color, 1.08);

            &:prelight {
                @include linear-gradient(mix($panel_bg_color, $panel_fg_color, .31), to top);

                border-color: mix($panel_bg_color, $panel_fg_color, .31);
            }
        }
    }

    PanelWidget, PanelApplet, PanelToplevel {
        @extend %panel;

        padding: 0;
    }

    PanelApplet {
        border: 0;

        .button {
            @extend %panelbutton;

            -GtkButton-inner-border: 2;
        }
    }

    PanelSeparator {
        @extend %panel;

        border: 0;
    }

    PanelApplet > GtkMenuBar.menubar, PanelMenuBar.menubar, .gnome-panel-menu-bar {
        &.menuitem {
            @extend %panel;

            border: 0;

            -PanelMenuBar-icon-visible: true;
        }
    }

    PanelAppletFrame {
        @extend %panel;

        border: 0;
    }

    WnckPager, WnckTasklist { @extend %panel; }
}
